"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const indexIjCGSjCy = require("./index-IjCGSjCy-L6RMj4xi.js");
const jsxRuntime = require("react/jsx-runtime");
const React = require("react");
const designSystem = require("@strapi/design-system");
const reactIntl = require("react-intl");
function _interopNamespace(e) {
  if (e && e.__esModule)
    return e;
  const n = Object.create(null, { [Symbol.toStringTag]: { value: "Module" } });
  if (e) {
    for (const k in e) {
      if (k !== "default") {
        const d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: () => e[k]
        });
      }
    }
  }
  n.default = e;
  return Object.freeze(n);
}
const React__namespace = /* @__PURE__ */ _interopNamespace(React);
function useReviewWorkflows(params = {}) {
  const { id = "", ...queryParams } = params;
  const { data, isLoading } = indexIjCGSjCy.useGetWorkflowsQuery({
    id,
    populate: "stages",
    ...queryParams
  });
  const [createWorkflow] = indexIjCGSjCy.useCreateWorkflowMutation();
  const [updateWorkflow] = indexIjCGSjCy.useUpdateWorkflowMutation();
  const [deleteWorkflow] = indexIjCGSjCy.useDeleteWorkflowMutation();
  const { workflows, meta } = data ?? {};
  return {
    // meta contains e.g. the total of all workflows. we can not use
    // the pagination object here, because the list is not paginated.
    meta,
    workflows,
    isLoading,
    createWorkflow,
    updateWorkflow,
    deleteWorkflow
  };
}
const AssigneeFilter = ({ name }) => {
  const [page, setPage] = React__namespace.useState(1);
  const { formatMessage } = reactIntl.useIntl();
  const { data, isLoading } = indexIjCGSjCy.useAdminUsers({
    page
  });
  const users = data?.users || [];
  const field = indexIjCGSjCy.useField(name);
  const handleChange = (value) => {
    setPage(1);
    field.onChange(name, value);
  };
  return /* @__PURE__ */ jsxRuntime.jsx(
    designSystem.Combobox,
    {
      value: field.value,
      "aria-label": formatMessage({
        id: "content-manager.components.Filters.usersSelect.label",
        defaultMessage: "Search and select an user to filter"
      }),
      onChange: handleChange,
      loading: isLoading,
      onLoadMore: () => setPage((prev) => prev + 1),
      children: users.map((user) => {
        return /* @__PURE__ */ jsxRuntime.jsx(designSystem.ComboboxOption, { value: user.id.toString(), children: indexIjCGSjCy.getDisplayName(user, formatMessage) }, user.id);
      })
    }
  );
};
const StageFilter = (props) => {
  const { model } = indexIjCGSjCy.useDoc();
  const { formatMessage } = reactIntl.useIntl();
  const { workflows, isLoading } = useReviewWorkflows({ filters: { contentTypes: model } });
  const field = indexIjCGSjCy.useField(props.name);
  const [workflow] = workflows ?? [];
  return /* @__PURE__ */ jsxRuntime.jsx(
    designSystem.SingleSelect,
    {
      "aria-label": formatMessage({
        id: "content-manager.components.Filters.reviewWorkflows.label",
        defaultMessage: "Search and select an workflow stage to filter"
      }),
      value: field.value,
      onChange: (value) => {
        field.onChange(props.name, value);
      },
      loading: isLoading,
      customizeContent: () => /* @__PURE__ */ jsxRuntime.jsxs(designSystem.Flex, { as: "span", justifyContent: "space-between", alignItems: "center", width: "100%", children: [
        /* @__PURE__ */ jsxRuntime.jsx(designSystem.Typography, { textColor: "neutral800", ellipsis: true, children: field.value }),
        isLoading ? /* @__PURE__ */ jsxRuntime.jsx(designSystem.Loader, { small: true, style: { display: "flex" } }) : null
      ] }),
      children: (workflow?.stages ?? []).map(({ id, color, name }) => {
        const { themeColorName } = indexIjCGSjCy.getStageColorByHex(color) ?? {};
        return /* @__PURE__ */ jsxRuntime.jsx(
          designSystem.SingleSelectOption,
          {
            startIcon: /* @__PURE__ */ jsxRuntime.jsx(
              designSystem.Flex,
              {
                height: 2,
                background: color,
                borderColor: themeColorName === "neutral0" ? "neutral150" : void 0,
                hasRadius: true,
                shrink: 0,
                width: 2
              }
            ),
            value: name,
            children: name
          },
          id
        );
      })
    }
  );
};
const REVIEW_WORKFLOW_COLUMNS_EE = [
  {
    name: indexIjCGSjCy.STAGE_ATTRIBUTE_NAME,
    attribute: {
      type: "relation",
      relation: "oneToMany",
      target: "admin::review-workflow-stage"
    },
    label: {
      id: indexIjCGSjCy.getTranslation(`containers.list.table-headers.reviewWorkflows.stage`),
      defaultMessage: "Review stage"
    },
    searchable: false,
    sortable: true,
    mainField: {
      name: "name",
      type: "string"
    }
  },
  {
    name: indexIjCGSjCy.ASSIGNEE_ATTRIBUTE_NAME,
    attribute: {
      type: "relation",
      target: "admin::user",
      relation: "oneToMany"
    },
    label: {
      id: indexIjCGSjCy.getTranslation(`containers.list.table-headers.reviewWorkflows.assignee`),
      defaultMessage: "Assignee"
    },
    searchable: false,
    sortable: true,
    mainField: {
      name: "firstname",
      type: "string"
    }
  }
];
const REVIEW_WORKFLOW_FILTERS = [
  {
    mainField: {
      name: "name",
      type: "string"
    },
    input: StageFilter,
    label: {
      id: indexIjCGSjCy.getTranslation(`containers.list.table-headers.reviewWorkflows.stage`),
      defaultMessage: "Review stage"
    },
    name: "strapi_stage",
    type: "relation"
  },
  {
    type: "relation",
    mainField: {
      name: "id",
      type: "integer"
    },
    input: AssigneeFilter,
    operators: [
      {
        label: {
          id: "components.FilterOptions.FILTER_TYPES.$eq",
          defaultMessage: "is"
        },
        value: "$eq"
      },
      {
        label: {
          id: "components.FilterOptions.FILTER_TYPES.$ne",
          defaultMessage: "is not"
        },
        value: "$ne"
      }
    ],
    label: {
      id: indexIjCGSjCy.getTranslation(`containers.list.table-headers.reviewWorkflows.assignee.label`),
      defaultMessage: "Assignee"
    },
    name: "strapi_assignee"
  }
];
exports.REVIEW_WORKFLOW_COLUMNS_EE = REVIEW_WORKFLOW_COLUMNS_EE;
exports.REVIEW_WORKFLOW_FILTERS = REVIEW_WORKFLOW_FILTERS;
//# sourceMappingURL=constants-65DlzZY_-iStVTVT9.js.map
